| Title: | igraph library as an R package |
|---|---|
| Description: | Vendors the igraph C source code and builds it into a static library. Other Bioconductor packages can link to libigraph.a in their own C/C++ code. This is intended for packages wrapping C/C++ libraries that depend on the igraph C library and cannot be easily adapted to use the igraph R package. |
| Authors: | Aaron Lun [cre, aut] |
| Maintainer: | Aaron Lun <[email protected]> |
| License: | GPL-3 |
| Version: | 1.5.1 |
| Built: | 2026-05-08 15:27:35 UTC |
| Source: | https://github.com/bioc/Rigraphlib |
Configure flags for compiling downstream packages.
pkgconfig(opt = c("PKG_CPPFLAGS", "PKG_LIBS"))pkgconfig(opt = c("PKG_CPPFLAGS", "PKG_LIBS"))
opt |
String specifying the |
If the RIGRAPHLIB_<OPT> environment variable is set (where <OPT> is replaced by opt),
the contents of that variable will be printed by this function,
regardless of any other settings.
If the RIGRAPHLIB_USE_SYSTEM_LIBRARY environment was set to 1 during Rigraphlib installation or is currently set to 1.
this function will print the output of pkg-config igraph relevant to the requested opt.
If igraph cannot be found by pkg-config, an error is thrown.
Otherwise, this function will print flags to link to the binaries generated from the vendored igraph source.
If any of the above environment variables are specified,
the version of the corresponding igraph instance should be consistent with that of the vendored igraph source.
See version(TRUE) for the expected version of the igraph library.
Flags to add to the requested opt of the Makevars are printed to the screen.
Aaron Lun
pkgconfig("PKG_CPPFLAGS") pkgconfig("PKG_LIBS")pkgconfig("PKG_CPPFLAGS") pkgconfig("PKG_LIBS")
Reports the version of the igraph library used by pkgconfig.
version(expected = FALSE)version(expected = FALSE)
expected |
Boolean indicating whether to report the version of igraph expected by Rigraphlib and its downstream dependencies. This corresponds to the version that is vendored into the Rigraphlib package. |
If the RIGRAPHLIB_LIBRARY_VERSION environment variable is set,
the contents of that variable will be returned by this function if expected=FALSE.
If the RIGRAPHLIB_USE_SYSTEM_LIBRARY variable was set to 1 during Rigraphlib installation or is currently set to 1,
the version of igraph reported by pkg-config is returned if expected=FALSE.
If igraph cannot be found by pkg-config, an error is thrown.
Otherwise, the version of the vendored igraph is returned.
If expected=FALSE, the actual version of the igraph library linked by pkgconfig.
If expected=TRUE, the expected version of the igraph library to be provided by Rigraphlib.
Rigraphlib::version()Rigraphlib::version()